@@ -176,7 +176,7 @@ class EngineManager:
     def _mssql_connection(self, env):
         """ בונה מחרוזת חיבור ל-MSSQL """
         self._check_required_fields(env, "mssql")
-        return f"mssql+pyodbc://{env['USER']}:{env['PASSWORD']}@{env['HOST']}/{env['NAME']}?driver={env['DRIVER']}"
+        return f"mssql+aioodbc://{env['USER']}:{env['PASSWORD']}@{env['HOST']}/{env['NAME']}?driver={env['DRIVER']}"
 
     """
     Builds a connection string for Oracle.
@@ -185,3 +185,19 @@ class EngineManager:
         """ בונה מחרוזת חיבור ל-Oracle """
         self._check_required_fields(env, "oracle")
         return f"oracle+oracledb://{env['USER']}:{env['PASSWORD']}@{env['HOST']}/{env['NAME']}"
+
+    """
+    Disposes all open database engines.
+
+    This method ensures that all database engines stored in the _engines dictionary
+    are properly closed. It iterates through each engine, calls the dispose method,
+    and clears the engines dictionary to free resources.
+    """
+    async def close_engines(self):
+        """Closes all active database engines."""
+        for env_file, engine in self._engines.items():
+            logger.info(f"Disposing engine for: {env_file}")
+            await engine.dispose()
+        self._engines.clear()
+        logger.info("All engines have been disposed.")
+
